==> haskell-invariant-0.5.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: invariant
version: 0.5.1
id: invariant-0.5.1-LRGVLQ3lFDZ1EOS9uRNiYQ
key: invariant-0.5.1-LRGVLQ3lFDZ1EOS9uRNiYQ
license: BSD-2-Clause
maintainer: Nicolas Frisby <nicolas.frisby@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
author: Nicolas Frisby <nicolas.frisby@gmail.com>
homepage: https://github.com/nfrisby/invariant-functors
synopsis: Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).
    .
    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":
    .
    <http://comonad.com/reader/2008/rotten-bananas/>
category: Control, Data
abi: a74881c4249684e6abed2524230a63d4
exposed: True
exposed-modules:
    Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules: Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs: /usr/lib/ghc-8.4.3/site-local/invariant-0.5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/invariant-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/invariant-0.5.1
hs-libraries: HSinvariant-0.5.1-LRGVLQ3lFDZ1EOS9uRNiYQ
depends:
    array-0.5.2.0 base-4.11.1.0 bifunctors-5.5.3-7I9H5KLoYs0DxdTsXIncCM
    comonad-5.0.4-1EfSpa6AA5U3LtobVlqSjD containers-0.5.11.0
    contravariant-1.5-HWHOmzUIRDZBjbL8Fw1HTI ghc-prim-0.5.2.0
    profunctors-5.3-IgECUkHj2LhJdroAs5SPJF
    StateVar-1.1.1.0-BmCYP2gLue736T5hzlFgTZ stm-2.4.5.0
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO template-haskell-2.13.0.0
    th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88 transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
abi-depends: array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bifunctors-5.5.3-7I9H5KLoYs0DxdTsXIncCM=19f0058dd031132b57741ec9a8f68b0e
             comonad-5.0.4-1EfSpa6AA5U3LtobVlqSjD=bee891a03b83d11cad862c41f78926bb
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             contravariant-1.5-HWHOmzUIRDZBjbL8Fw1HTI=745e81e7e3650c93ab38811415728ba3
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             profunctors-5.3-IgECUkHj2LhJdroAs5SPJF=27920699c0331e1500e4159f354cda5a
             StateVar-1.1.1.0-BmCYP2gLue736T5hzlFgTZ=45bb6a3be5c8b9b97b4f8b0fdd8aa1dc
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88=303b2de9b3dc2b2e86b6ff0f8de41846
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
haddock-interfaces: /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html: /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-invariant-0.5.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: invariant
version: 0.5.1
id: invariant-0.5.1-BK5EGK9NHLbGa4us8wUvxK
key: invariant-0.5.1-BK5EGK9NHLbGa4us8wUvxK
license: BSD-2-Clause
maintainer: Nicolas Frisby <nicolas.frisby@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
author: Nicolas Frisby <nicolas.frisby@gmail.com>
homepage: https://github.com/nfrisby/invariant-functors
synopsis: Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).
    .
    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":
    .
    <http://comonad.com/reader/2008/rotten-bananas/>
category: Control, Data
abi: 7c8c2cbaeb6af01e71d9b26b401d8080
exposed: True
exposed-modules:
    Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules: Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs: /usr/lib/ghc-8.4.3/site-local/invariant-0.5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/invariant-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/invariant-0.5.1
hs-libraries: HSinvariant-0.5.1-BK5EGK9NHLbGa4us8wUvxK
depends:
    array-0.5.2.0 base-4.11.1.0 bifunctors-5.5.3-BWXHhQ4CJ6lH9XkjWypCPC
    comonad-5.0.4-3a3eb7VXjyTBj8gF3eWZTj containers-0.5.11.0
    contravariant-1.5-HWHOmzUIRDZBjbL8Fw1HTI ghc-prim-0.5.2.0
    profunctors-5.3-4704WQ9ngLC3F8GtGRMbw8
    StateVar-1.1.1.0-BmCYP2gLue736T5hzlFgTZ stm-2.4.5.0
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO template-haskell-2.13.0.0
    th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88 transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
abi-depends: array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bifunctors-5.5.3-BWXHhQ4CJ6lH9XkjWypCPC=7846388f25f824ab5253f4b4cfd76886
             comonad-5.0.4-3a3eb7VXjyTBj8gF3eWZTj=8fdc4dc9241d421d8cd18312b441b5e8
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             contravariant-1.5-HWHOmzUIRDZBjbL8Fw1HTI=745e81e7e3650c93ab38811415728ba3
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             profunctors-5.3-4704WQ9ngLC3F8GtGRMbw8=0fbd1f79d0d70fa90203563792d0ce68
             StateVar-1.1.1.0-BmCYP2gLue736T5hzlFgTZ=45bb6a3be5c8b9b97b4f8b0fdd8aa1dc
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88=303b2de9b3dc2b2e86b6ff0f8de41846
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
haddock-interfaces: /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html: /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
